You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@aries.apache.org by no...@apache.org on 2009/11/26 17:49:17 UTC

svn commit: r884637 - /incubator/aries/trunk/application/application-utils/src/main/java/org/apache/aries/application/VersionRange.java

Author: not
Date: Thu Nov 26 16:49:17 2009
New Revision: 884637

URL: http://svn.apache.org/viewvc?rev=884637&view=rev
Log:
ARIES-55 updates to the version range interface

Modified:
    incubator/aries/trunk/application/application-utils/src/main/java/org/apache/aries/application/VersionRange.java

Modified: incubator/aries/trunk/application/application-utils/src/main/java/org/apache/aries/application/VersionRange.java
URL: http://svn.apache.org/viewvc/incubator/aries/trunk/application/application-utils/src/main/java/org/apache/aries/application/VersionRange.java?rev=884637&r1=884636&r2=884637&view=diff
==============================================================================
--- incubator/aries/trunk/application/application-utils/src/main/java/org/apache/aries/application/VersionRange.java (original)
+++ incubator/aries/trunk/application/application-utils/src/main/java/org/apache/aries/application/VersionRange.java Thu Nov 26 16:49:17 2009
@@ -20,52 +20,56 @@
 
 import org.osgi.framework.Version;
 
-public interface VersionRange {
-
-	public abstract String toString();
-
-	/**
-	 * this method returns the exact version from the versionInfo obj.
-	 * this is used for DeploymentContent only to return a valid exact version
-	 * otherwise, null is returned.
-	 * @return
-	 */
-	public abstract Version getExactVersion();
-
-	/**
-	 * get the maximum version
-	 * @return    the maximum version
-	 */
-	public abstract Version getMaximumVersion();
-
-	/**
-	 * get the minimum version
-	 * @return    the minimum version
-	 */
-	public abstract Version getMinimumVersion();
-
-	/**
-	 * is the maximum version exclusive
-	 * @return  
-	 */
-	public abstract boolean isMaximumExclusive();
-
-	/**
-	 * is the maximum version unbounded
-	 * @return
-	 */
-	public abstract boolean isMaximumUnbounded();
-
-	/**
-	 * is the minimum version exclusive
-	 * @return
-	 */
-	public abstract boolean isMinimumExclusive();
-
-	/**
-	 * check if the versioninfo is the exact version
-	 * @return
-	 */
-	public abstract boolean isExactVersion();
-
-}
+public interface VersionRange
+{
+  /**
+   * this method returns the exact version from the versionInfo obj.
+   * this is used for DeploymentContent only to return a valid exact version
+   * otherwise, null is returned.
+   * @return
+   */
+  public abstract Version getExactVersion();
+
+  /**
+   * get the maximum version
+   * @return    the maximum version
+   */
+  public abstract Version getMaximumVersion();
+
+  /**
+   * get the minimum version
+   * @return    the minimum version
+   */
+  public abstract Version getMinimumVersion();
+
+  /**
+   * is the maximum version exclusive
+   * @return  
+   */
+  public abstract boolean isMaximumExclusive();
+
+  /**
+   * is the maximum version unbounded
+   * @return
+   */
+  public abstract boolean isMaximumUnbounded();
+
+  /**
+   * is the minimum version exclusive
+   * @return
+   */
+  public abstract boolean isMinimumExclusive();
+
+  /**
+   * check if the versioninfo is the exact version
+   * @return
+   */
+  public abstract boolean isExactVersion();
+  /**
+   * This method tests to see if the provided version is inside this range.
+   * 
+   * @param version the version to test.
+   * @return        true if the version matches, false otherwise.
+   */
+  public boolean matches(Version version);
+}
\ No newline at end of file